sagemath_gap_pkg_jupyterkernel: Native Jupyter kernel for GAP (kernelspec)
==========================================================================

Description
-----------

This is the pip-installed part of the GAP package JupyterKernel.

See also: ``gap_pkg_jupyterkernel``


License
-------

BSD-3-Clause license


Upstream Contact
----------------

- https://pypi.org/project/passagemath-gap-pkg-jupyterkernel/
- https://github.com/gap-packages/JupyterKernel
